==> cdk_2.3.orig.tar.gz: cdk-cdk-2.3/storage/ioformats/src/test/java/org/openscience/cdk/io/formats/MOPAC93FormatTest.java <==
/* Copyright (C) 2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@slists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.io.formats;

import org.junit.Assert;
import org.junit.Test;

/**
 * @cdk.module test-ioformats
 */
public class MOPAC93FormatTest extends ChemFormatMatcherTest {

    public MOPAC93FormatTest() {
        super.setChemFormatMatcher((IChemFormatMatcher) MOPAC93Format.getInstance());
    }

    @Test
    public void testMatchesMopac93() throws Exception {
        Assert.assertTrue(((MOPAC93Format) MOPAC93Format.getInstance()).matches(0,
                "*                   MOPAC  93.00               CALC'D. Mon May 31 20:29:07 2004"));
    }
}

==> cdk_2.10.orig.tar.gz: cdk-cdk-2.10/storage/ioformats/src/test/java/org/openscience/cdk/io/formats/MOPAC93FormatTest.java <==
/* Copyright (C) 2008  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@slists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.io.formats;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * @cdk.module test-ioformats
 */
class MOPAC93FormatTest extends ChemFormatMatcherTest {

    MOPAC93FormatTest() {
        super.setChemFormatMatcher((IChemFormatMatcher) MOPAC93Format.getInstance());
    }

    @Test
    void testMatchesMopac93() throws Exception {
        Assertions.assertTrue(((MOPAC93Format) MOPAC93Format.getInstance()).matches(0,
                                                                                    "*                   MOPAC  93.00               CALC'D. Mon May 31 20:29:07 2004"));
    }
}
